# Intentify

A python library for training intent classification models.

## Setting Up A Basic Model

```python

from intentify import Intentify

file_path = 'intents.json'
name = 'test_model'

Model = Intentify(file_path, model_name=name)
Model.train_model()
Model.save_model()

done = False

while not done:
    message = input("You: ")
    if message == "STOP":
        done = True
    else:
        response = Model.request(message)
        print(response)
```

## Binding Functions To Requests

```python
from intentify import Intentify

def function_for_greetings():
    print("Greetings Intent Trigger!")
    # Some action you want to take

def function_for_stocks():
    print("Stocks Intent Trigger!")
    # Some action you want to take

mappings = {'greeting' : function_for_greetings, 'stocks' : function_for_stocks}
file_path = 'intents.json'
name = 'test_model'

Model = Intentify(file_path, intent_methods=mappings ,model_name=name)
Model.train_model()
Model.save_model()

done = False

while not done:
    message = input("Enter a message: ")
    if message == "STOP":
        done = True
    else:
        Model.request(message)

```

Once you have saved the model you can simply call "Model.load_model()" instead of ".train_model()" and ".save_model()"


## Sample intents.json File
```json
{"intents": [
  {"tag": "greeting",
    "patterns": ["Hi", "How are you", "Is anyone there?", "Hello", "Good day", "Whats up", "Hey", "greetings"],
    "responses": ["Hello!", "Good to see you again!", "Hi there, how can I help?"],
    "context_set": ""
  },
  {"tag": "goodbye",
    "patterns": ["cya", "See you later", "Goodbye", "I am Leaving", "Have a Good day", "bye", "cao", "see ya"],
    "responses": ["Sad to see you go :(", "Talk to you later", "Goodbye!"],
    "context_set": ""
  },
  {"tag": "stocks",
    "patterns": ["what stocks do I own?", "how are my shares?", "what companies am I investing in?", "what am I doing in the markets?"],
    "responses": ["You own the following shares: ABBV, AAPL, FB, NVDA and an ETF of the S&P 500 Index!"],
    "context_set": ""
  }
]
}
```